.. _publications_rst

Publications
############

If you use |yggdrasil| in your work, please cite the publication below.

 - Meagan Lang, yggdrasil: a Python package for integrating computational models 
   across languages and scales, in silico Plants, Volume 1, Issue 1, 2019, diz001, 
   `https://doi.org/10.1093/insilicoplants/diz001 <https://doi.org/10.1093/insilicoplants/diz001>`__

.. Additional |yggdrasil| Publications
   ===================================

   Publications Using |yggdrasil|
   ==============================
